-- ==============================================================
-- FILE : HE_SCLK.VHD  -  DO NOT EDIT THIS FILE
-- ==============================================================
--
-- This file is part of the Hardware Interface Layer (H.I.L) of
-- your project when using your HERON-IO2V2 module.
--
-- This file must NOT be modified by users of the Module.
--
-- ==============================================================
--
--  Module      : HE_SCLK
--  Date        : 07/05/2002
--  Author      : R. Williams - HUNT ENGINEERING
--  Description : ADC clock control for A and B channels
--
-- ==============================================================
--
--  Ver     Modified By      Date      Changes
--  ---     -----------      ----      -------
--  1.0     R. Williams    07-05-02    First Written
--  1.2     R. Williams    08-05-02    Syntax change made to all
--                                     instanciated components,
--                                     (changed '0' to GND)
--                                     for compatibility with
--                                     ModelSim5.5b.
--  2.0     R. Williams    10-05-02    Adapted for the IO2V2 from
--                                     IO2V1.
--  2.1     R. Williams    05-07-02    Added 1ns delay on paths
--                                     from inferred flip-flops
--                                     to instantiated flip-flops
--                                     to prevent setup violations
--                                     in functional simulation
--  2.2     R. Williams    10-10-02    New components added for
--                                     interfacing to all six HERON
--                                     input FIFOs and all six HERON
--                                     output FIFOs at the same time.
--                                     Added component HE_RD_6F in
--                                     place of component HE_RD_1F.
--                                     Added component HE_WR_6F in
--                                     place of component HE_WR_1F.
--  2.3     R. Williams    20-01-03    Changes made to the HSB
--                                     mastering functions, and 
--                                     additional registering added
--                                     to the AE flag to ensure
--                                     correct reading from HEPC8s.
--
-- ==============================================================


library IEEE;
  use IEEE.std_logic_1164.all;

-- synopsys translate_off
library UNISIM;
  use UNISIM.vcomponents.all;
-- synopsys translate_on

entity HE_SCLK is
  generic ( CommonClock : boolean;
            DriveClockA : boolean );
  port (
    -- module I/Os
    SCK_A  : in  std_logic;
    SCK_B  : in  std_logic;
    SCLK_A : out std_logic;
    SCLK_B : out std_logic;
    OEN_A  : out std_logic;
    OEN_B  : out std_logic
  );
end HE_SCLK;


architecture RTL of HE_SCLK is

  component BUFG
    port(I : in  std_logic;
         O : out std_logic);
  end component;

  signal OE_A    : std_logic;
  signal OE_B    : std_logic;

begin

  gIntClk : if DriveClockA generate
    OE_A <= '0'; 
  end generate;

  gExtClk : if (NOT DriveClockA) generate
    OE_A <= '1';
  end generate;

  gCmnClk : if CommonClock generate
    OE_B <= '1';
  end generate;

  gNCmnClk : if (NOT CommonClock) generate
    OE_B <= '0';
  end generate;

  OEN_A <= OE_A;
  OEN_B <= OE_B;

  iBUFG_A : BUFG port map (I=>SCK_A, O=>SCLK_A);
  iBUFG_B : BUFG port map (I=>SCK_B, O=>SCLK_B);

end RTL;
